==> geopsypack-src-3.3.4.tar.gz: geopsypack-src-3.3.4/QGpCoreWave/src/AutocorrDispersion.h <==
/***************************************************************************
**
**  This file is part of QGpCoreWave.
**
**  This library is free software; you can redistribute it and/or
**  modify it under the terms of the GNU Lesser General Public
**  License as published by the Free Software Foundation; either
**  version 2.1 of the License, or (at your option) any later version.
**
**  This file is distributed in the hope that it will be useful, but WITHOUT
**  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
**  FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
**  License for more details.
**
**  You should have received a copy of the GNU Lesser General Public
**  License along with this library; if not, write to the Free Software
**  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2009-02-04
**  Copyright: 2009-2019
**    Marc Wathelet
**    Marc Wathelet (LGIT, Grenoble, France)
**
***************************************************************************/

#ifndef AUTOCORRDISPERSION_H
#define AUTOCORRDISPERSION_H

#include "AutocorrEngine.h"
#include "QGpCoreWaveDLLExport.h"

namespace QGpCoreWave {

class QGPCOREWAVE_EXPORT AutocorrDispersion : private AutocorrEngine
{
public:
  void setRing(const AutocorrRing& r) {setVerticalRing(r);}
  QVector<double> dispersion(const FactoryPoint& autocorr, double kmin, double kmax);

  double y(double k);
  double derivative(double k);
private:
  double _autocorrRef;
};

} // namespace QGpCoreWave

#endif // AUTOCORRDISPERSION_H

==> geopsypack-src-3.4.1.tar.gz: geopsypack-src-3.4.1/QGpCoreWave/src/AutocorrDispersion.h <==
/***************************************************************************
**
**  This file is part of QGpCoreWave.
**
**  This library is free software; you can redistribute it and/or
**  modify it under the terms of the GNU Lesser General Public
**  License as published by the Free Software Foundation; either
**  version 2.1 of the License, or (at your option) any later version.
**
**  This file is distributed in the hope that it will be useful, but WITHOUT
**  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
**  FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
**  License for more details.
**
**  You should have received a copy of the GNU Lesser General Public
**  License along with this library; if not, write to the Free Software
**  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2009-02-04
**  Copyright: 2009-2019
**    Marc Wathelet
**    Marc Wathelet (LGIT, Grenoble, France)
**
***************************************************************************/

#ifndef AUTOCORRDISPERSION_H
#define AUTOCORRDISPERSION_H

#include "AutocorrEngine.h"
#include "QGpCoreWaveDLLExport.h"

namespace QGpCoreWave {

class QGPCOREWAVE_EXPORT AutocorrDispersion : private AutocorrEngine
{
public:
  void setRing(const AutocorrRing& r) {setVerticalRing(r);}
  QVector<double> dispersion(double omega, double autocorr,
                             double kmin, double kmax);

  double y(double k);
private:
  double _autocorrRef;
};

} // namespace QGpCoreWave

#endif // AUTOCORRDISPERSION_H
